import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToMany, OneToOne, ManyToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { Agreement } from './agreement.type';
import { IsDate, IsNotEmpty, IsNumber, IsOptional } from 'class-validator';
import { UserConsultant } from './userConsultant.type';

export enum VisitStatus {
  SCHEDULED = 1,
  DONE = 2,
  PENDING = 3,
  LATE = 4
}

@Entity()
export class Visit extends BasicREntity {

  @IsNotEmpty()
  @ManyToOne(type => UserConsultant, userConsultant => userConsultant.visits, { nullable: false })
  consultant: UserConsultant;
 
  @IsNotEmpty()
  @ManyToOne(type => Agreement, agreement => agreement.visits, { nullable: false })
  agreement: Agreement;

  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  actualDate: Date;

  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  competence: Date;

  @IsOptional()
  @IsNumber()
  @Column({ nullable: false, type: 'int', default: 1 })
  status: VisitStatus;
}